@@ -713,11 +713,7 @@ debug_window_new(void)
 	width  = purple_prefs_get_int(PIDGIN_PREFS_ROOT "/debug/width");
 	height = purple_prefs_get_int(PIDGIN_PREFS_ROOT "/debug/height");
 
-#ifdef USE_HILDON
 	win->window = pidgin_create_window(_("Debug Window"), 0, "debug", TRUE);
-#else /* !USE_HILDON */
-	win->window = pidgin_create_dialog(_("Debug Window"), 0, "debug", TRUE);
-#endif /* USE_HILDON */
 	purple_debug_info("gtkdebug", "Setting dimensions to %d, %d\n",
 					width, height);
 
@@ -745,12 +741,8 @@ debug_window_new(void)
 #endif /* HAVE_REGEX_H */
 
 	/* Setup the vbox */
-#ifdef USE_HILDON
-	vbox = g_object_new(GTK_TYPE_VBOX, "visible", TRUE, NULL);
+	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(win->window), vbox);
-#else /* !USE_HILDON */
-	vbox = pidgin_dialog_get_vbox(GTK_DIALOG(win->window));
-#endif /* USE_HILDON */
 
 	if (purple_prefs_get_bool(PIDGIN_PREFS_ROOT "/debug/toolbar")) {
 		/* Setup our top button bar thingie. */
@@ -807,11 +799,12 @@ debug_window_new(void)
 		gtk_toolbar_insert_space(GTK_TOOLBAR(toolbar), -1);
 
 		/* regex toggle button */
+		image = gtk_image_new_from_stock(GTK_STOCK_FIND, GTK_ICON_SIZE_MENU);
 		win->filter =
 			gtk_toolbar_append_element(GTK_TOOLBAR(toolbar),
 									   GTK_TOOLBAR_CHILD_TOGGLEBUTTON,
 									   NULL, _("Filter"), _("Filter"),
-									   NULL, NULL,
+									   NULL, image,
 									   G_CALLBACK(regex_filter_toggled_cb),
 									   win);
 		/* we purposely disable the toggle button here in case
