@@ -91,11 +91,11 @@ typedef enum {
 } GtkIMHtmlSmileyFlags;
 
 struct _GtkIMHtml {
-#if HILDON_CHECK_VERSION(2,1,0)
+#ifdef HAVE_HILDON_TEXT_VIEW
 	HildonTextView text_view;
-#else /* HILDON < 2.1.0 */
+#else /* !HAVE_HILDON_TEXT_VIEW */
 	GtkTextView text_view;
-#endif /* HILDON >= 2.1.0 */
+#endif /* HAVE_HILDON_TEXT_VIEW */
 	GtkTextBuffer *text_buffer;
 	GdkCursor *hand_cursor;
 	GdkCursor *arrow_cursor;
@@ -155,11 +155,11 @@ struct _GtkIMHtml {
 };
 
 struct _GtkIMHtmlClass {
-#if HILDON_CHECK_VERSION(2,1,0)
+#ifdef HAVE_HILDON_TEXT_VIEW
 	HildonTextViewClass parent_class;
-#else /* HILDON < 2.1.0 */
+#else /* !HAVE_HILDON_TEXT_VIEW */
 	GtkTextViewClass parent_class;
-#endif /* HILDON >= 2.1.0 */
+#endif /* HAVE_HILDON_TEXT_VIEW */
 
 	void (*url_clicked)(GtkIMHtml *, const gchar *);
 	void (*buttons_update)(GtkIMHtml *, GtkIMHtmlButtons);
