@@ -528,7 +528,7 @@ static void plugin_dialog_response_cb(GtkWidget *d, int response, GtkTreeSelecti
 
 		g_signal_connect(G_OBJECT(dialog), "response", G_CALLBACK(pref_dialog_response_cb), plug);
 #ifdef USE_HILDON
-		box = _pidgin_make_container_scrollable(box, -1, -1);
+		box = _pidgin_make_container_scrollable(box);
 #endif /* USE_HILDON */
 		gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), box);
 		gtk_window_set_role(GTK_WINDOW(dialog), "plugin_config");
@@ -805,7 +805,7 @@ void pidgin_plugin_dialog_show()
 	gtk_expander_set_use_markup(GTK_EXPANDER(expander), TRUE);
 	gtk_widget_set_sensitive(expander, FALSE);
 #ifdef USE_HILDON
-	gtk_container_add(GTK_CONTAINER(expander), _pidgin_make_container_scrollable(create_details(), -1, -1));
+	gtk_container_add(GTK_CONTAINER(expander), _pidgin_make_container_scrollable(create_details()));
 #else /* !USE_HILDON */
 	gtk_container_add(GTK_CONTAINER(expander), create_details());
 #endif /* USE_HILDON */
